==> openjdk-9.0.7-c_compilervs2015_1015.tar.bz2: jdk.accessibility/module-info.java <==
/*
 * Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/**
 * Defines JDK utility classes used by implementors of Assistive Technologies.
 *
 * @moduleGraph
 * @since 9
 */
module jdk.accessibility {
    // source file: file:///c:/jenkins/workspace/zulu9-silver-build-win64/zulu-src/jdk/src/jdk.accessibility/share/classes/module-info.java
    //              file:///c:/jenkins/workspace/zulu9-silver-build-win64/zulu-src/jdk/src/jdk.accessibility/windows/classes/module-info.java.extra
    requires transitive java.desktop;
    exports com.sun.java.accessibility.util;

    provides javax.accessibility.AccessibilityProvider with com.sun.java.accessibility.internal.ProviderImpl;
}

==> openjdk-11.0.1-c_compilervs2008_1015.tar.bz2: jdk.accessibility/module-info.java <==
/*
 * Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/**
 * Defines JDK utility classes used by implementors of Assistive Technologies.
 *
 * @moduleGraph
 * @since 9
 */
module jdk.accessibility {
    // source file: file:///c:/jenkins/workspace/zulu11-build-win64/zulu-src/src/jdk.accessibility/share/classes/module-info.java
    //              file:///c:/jenkins/workspace/zulu11-build-win64/zulu-src/src/jdk.accessibility/windows/classes/module-info.java.extra
    requires transitive java.desktop;
    exports com.sun.java.accessibility.util;

    provides javax.accessibility.AccessibilityProvider with com.sun.java.accessibility.internal.ProviderImpl;
}
